==> 1.3.0.tar.gz: lib/src/widgets_live_result.dart <==
part of '../flutterx_live_data.dart';

class LiveResultBuilder<T> extends StatelessWidget {
  final LiveResult<T> result;

  final WidgetBuilder idleBuilder;
  final WidgetBuilder loaderBuilder;
  final LiveWidgetBuilder<T> successBuilder;
  final LiveWidgetBuilder errorBuilder;

  const LiveResultBuilder(
      {Key? key,
      required this.result,
      required this.idleBuilder,
      required this.loaderBuilder,
      required this.successBuilder,
      required this.errorBuilder})
      : super(key: key);

  @override
  StatelessElement createElement() => _LiveResultBuilderElement<T>(this);

  @override
  Widget build(BuildContext context) {
    switch (result.state) {
      case ResultState.idle:
        return idleBuilder(context);
      case ResultState.loading:
        return loaderBuilder(context);
      case ResultState.error:
        return errorBuilder(context, result._value);
      case ResultState.success:
        return successBuilder(context, result._value);
    }
  }

  @override
  void debugFillProperties(DiagnosticPropertiesBuilder properties) => super.debugFillProperties(properties
    ..add(DiagnosticsProperty<LiveResult<T>>('result', result))
    ..add(ObjectFlagProperty<WidgetBuilder>.has('idleBuilder', idleBuilder))
    ..add(ObjectFlagProperty<WidgetBuilder>.has('loaderBuilder', loaderBuilder))
    ..add(ObjectFlagProperty<LiveWidgetBuilder<T>>.has('successBuilder', successBuilder))
    ..add(ObjectFlagProperty<LiveWidgetBuilder>.has('errorBuilder', errorBuilder)));
}

class _LiveResultBuilderElement<T> extends StatelessElement with _LiveDataBuilderMixin<T, LiveResultBuilder<T>> {
  _LiveResultBuilderElement(LiveResultBuilder<T> widget) : super(widget);

  @override
  bool dataChanged(LiveResultBuilder<T> oldWidget, LiveResultBuilder<T> newWidget) =>
      !identical(oldWidget.result, newWidget.result);

  @override
  void link(LiveResultBuilder<T> widget) =>
      widget.result._state.observeForever(onChanged, dispatcher: Dispatcher.postFrame);

  @override
  void unlink(LiveResultBuilder<T> widget) => widget.result._state.removeObserver(onChanged);
}

==> 1.4.5.tar.gz: lib/src/widgets_live_result.dart <==
part of '../flutterx_live_data.dart';

/// A [Widget] whose content is built from the observed [LiveResult]
class LiveResultBuilder<T> extends StatelessWidget {
  /// Data which is observed
  final LiveResult<T> result;

  /// Widget builder function when state is [ResultState.idle]
  final WidgetBuilder idleBuilder;

  /// Widget builder function when state is [ResultState.loading]
  final WidgetBuilder loaderBuilder;

  /// Widget builder function when state is [ResultState.success]
  final LiveWidgetBuilder<T> successBuilder;

  /// Widget builder function when state is [ResultState.error]
  final LiveWidgetBuilder errorBuilder;

  /// Create builders from [result]
  const LiveResultBuilder({
    Key? key,
    required this.result,
    required this.idleBuilder,
    required this.loaderBuilder,
    required this.successBuilder,
    required this.errorBuilder,
  }) : super(key: key);

  @override
  StatelessElement createElement() => _LiveResultBuilderElement<T>(this);

  @override
  Widget build(BuildContext context) {
    switch (result.state) {
      case ResultState.idle:
        return idleBuilder(context);
      case ResultState.loading:
        return loaderBuilder(context);
      case ResultState.error:
        return errorBuilder(context, result._value);
      case ResultState.success:
        return successBuilder(context, result._value);
    }
  }

  @override
  void debugFillProperties(DiagnosticPropertiesBuilder properties) => super.debugFillProperties(properties
    ..add(DiagnosticsProperty<LiveResult<T>>('result', result))
    ..add(ObjectFlagProperty<WidgetBuilder>.has('idleBuilder', idleBuilder))
    ..add(ObjectFlagProperty<WidgetBuilder>.has('loaderBuilder', loaderBuilder))
    ..add(ObjectFlagProperty<LiveWidgetBuilder<T>>.has('successBuilder', successBuilder))
    ..add(ObjectFlagProperty<LiveWidgetBuilder>.has('errorBuilder', errorBuilder)));
}

class _LiveResultBuilderElement<T> extends StatelessElement with _LiveDataBuilderMixin<T, LiveResultBuilder<T>> {
  _LiveResultBuilderElement(LiveResultBuilder<T> widget) : super(widget);

  @override
  bool dataChanged(LiveResultBuilder<T> oldWidget, LiveResultBuilder<T> newWidget) =>
      !identical(oldWidget.result, newWidget.result);

  @override
  void link(LiveResultBuilder<T> widget) =>
      widget.result._state.observeForever(onChanged, dispatcher: Dispatcher.postFrame);

  @override
  void unlink(LiveResultBuilder<T> widget) => widget.result._state.removeObserver(onChanged);
}
